@@ -73,6 +73,7 @@ macro_rules! command_list {
     stats       Infer data types and compute descriptive statistics
     table       Align CSV data into columns
     transpose   Transpose rows/columns of CSV data
+    validate    Validate CSV data with JSON Schema
 
     sponsored by datHere - Data Infrastructure Engineering
 "
@@ -94,7 +95,6 @@ Options:
     --list               List all commands available.
     --envlist            List all qsv-relevant environment variables.
     -u, --update         Update qsv to the latest release from GitHub.
-    --skip-update-check  Skip automatic update check.
     -h, --help           Display this message
     <command> -h         Display the command help message
     -v, --version        Print version info, mem allocator, max_jobs, num_cpus then exit
@@ -109,7 +109,6 @@ struct Args {
     flag_list: bool,
     flag_envlist: bool,
     flag_update: bool,
-    flag_skip_update_check: bool,
 }
 
 fn main() {
@@ -119,7 +118,7 @@ fn main() {
 
     if log_enabled!(Level::Info) {
         let qsv_args: String = env::args().skip(1).collect::<Vec<_>>().join(" ");
-        info!("START: {}", qsv_args);
+        info!("START: {qsv_args}");
     }
 
     let args: Args = Docopt::new(USAGE)
@@ -137,10 +136,7 @@ fn main() {
         return;
     }
     if args.flag_update {
-        if let Err(err) = util::qsv_update(true) {
-            werr!("{}", err);
-            ::std::process::exit(1);
-        }
+        util::qsv_check_for_update("qsvlite");
         return;
     }
     match args.arg_command {
@@ -151,16 +147,8 @@ fn main() {
 Please choose one of the following commands:",
                 command_list!()
             ));
-            if !args.flag_skip_update_check {
-                if let Err(err) = util::qsv_update(false) {
-                    werr!("{}", err);
-                    ::std::process::exit(1);
-                } else {
-                    ::std::process::exit(0);
-                }
-            } else {
-                ::std::process::exit(0);
-            }
+            util::qsv_check_for_update("qsvlite");
+            ::std::process::exit(0);
         }
         Some(cmd) => match cmd.run() {
             Ok(()) => {
@@ -172,9 +160,9 @@ Please choose one of the following commands:",
             Err(CliError::Flag(err)) => err.exit(),
             Err(CliError::Csv(err)) => {
                 if log_enabled!(Level::Error) {
-                    error!("{}", err);
+                    error!("{err}");
                 } else {
-                    werr!("{}", err);
+                    werr!("{err}");
                 }
                 process::exit(1);
             }
@@ -183,17 +171,17 @@ Please choose one of the following commands:",
             }
             Err(CliError::Io(err)) => {
                 if log_enabled!(Level::Error) {
-                    error!("{}", err);
+                    error!("{err}");
                 } else {
-                    werr!("{}", err);
+                    werr!("{err}");
                 }
                 process::exit(1);
             }
             Err(CliError::Other(msg)) => {
                 if log_enabled!(Level::Error) {
-                    error!("{}", msg);
+                    error!("{msg}");
                 } else {
-                    werr!("{}", msg);
+                    werr!("{msg}");
                 }
                 process::exit(1);
             }
@@ -238,6 +226,7 @@ enum Command {
     Stats,
     Table,
     Transpose,
+    Validate,
 }
 
 impl Command {
@@ -268,7 +257,8 @@ impl Command {
             Command::Frequency => cmd::frequency::run(argv),
             Command::Headers => cmd::headers::run(argv),
             Command::Help => {
-                wout!("{}", USAGE);
+                wout!("{USAGE}");
+                util::qsv_check_for_update("qsvlite");
                 Ok(())
             }
             Command::Index => cmd::index::run(argv),
@@ -290,6 +280,7 @@ impl Command {
             Command::Stats => cmd::stats::run(argv),
             Command::Table => cmd::table::run(argv),
             Command::Transpose => cmd::transpose::run(argv),
+            Command::Validate => cmd::validate::run(argv),
         }
     }
 }
@@ -353,6 +344,6 @@ impl<'a> From<&'a str> for CliError {
 
 impl From<regex::Error> for CliError {
     fn from(err: regex::Error) -> CliError {
-        CliError::Other(format!("{:?}", err))
+        CliError::Other(format!("{err:?}"))
     }
 }
